import test from 'tape';
import Immutable from 'seamless-immutable';

import mount, { reducer, type } from './mount';


test('should mount state if undefined', (t) => {
    const root = 'test';

    const action = mount({ initialComponentState: { my: 'state' }, root });
    const state = reducer[type](Immutable({ meta: { mounted: {} } }), action);

    t.same(state, { [root]: { my: 'state' }, meta: { mounted: { [root]: true } } });
    t.end();
});

test('should mount state if defined but not marked as mounted', (t) => {
    const root = 'test';

    const action = mount({ initialComponentState: { my: 'state' }, root });
    const state = reducer[type](Immutable({ [root]: { yada: 'yada, yada' }, meta: { mounted: {} } }), action);

    t.same(state, { [root]: { my: 'state' }, meta: { mounted: { [root]: true } } });
    t.end();
});

test('should not re-mount state', (t) => {
    const root = 'test';

    const action = mount({ initialComponentState: { my: 'state' }, root });
    const state = reducer[type](Immutable({ meta: { mounted: {} } }), action);

    const raction = mount({ initialComponentState: { my: 'new-state' }, root });
    const rstate = reducer[type](state, raction);

    t.same(rstate, { [root]: { my: 'state' }, meta: { mounted: { [root]: true } } });
    t.end();
});
